BubbleConfiguration class
Constructors
- BubbleConfiguration({Widget senderProfileBuilder(BuildContext context, String name)?, Widget receiverProfileBuilder(BuildContext context, String name)?, Widget senderBubbleBuilder(BuildContext context, Widget child)?, Widget receiverBubbleBuilder(BuildContext context, Widget child)?, Widget timeBuilder(BuildContext context, String name)?, Widget loadingWidget = const MessageLoading(), double maxWidth = double.infinity, EdgeInsetsGeometry? padding = const EdgeInsets.all(16), TextStyle? profileNameStyle, TextStyle? timeStyle, Widget readIndicatorBuilder(BuildContext context, bool isRead)?})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- loadingWidget → Widget
-
final
- maxWidth → double
-
final
- padding → EdgeInsetsGeometry?
-
final
- profileNameStyle → TextStyle?
-
final
- readIndicatorBuilder → Widget Function(BuildContext context, bool isRead)?
-
final
- receiverBubbleBuilder → Widget Function(BuildContext context, Widget child)?
-
final
- receiverProfileBuilder → Widget Function(BuildContext context, String name)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderBubbleBuilder → Widget Function(BuildContext context, Widget child)?
-
final
- senderProfileBuilder → Widget Function(BuildContext context, String name)?
-
final
- timeBuilder → Widget Function(BuildContext context, String name)?
-
final
- timeStyle → TextStyle?
-
final
Methods
-
buildBubble(
BuildContext context, Widget child, bool isSender) → Widget -
buildProfile(
BuildContext context, String name, bool isSender) → Widget -
buildTime(
BuildContext context, String timestamp) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited