FailedMessageEntry class

Constructors

FailedMessageEntry({required String messageId, required MessageGroup messageGroup, required MessageDispatchCallback onDispatch})

Properties

hashCode int
The hash code for this object.
no setterinherited
messageGroup MessageGroup
final
messageId String
final
onDispatch MessageDispatchCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MessageGroup? messageGroup, MessageDispatchCallback? onDispatch}) FailedMessageEntry
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited