SenderMessage class

Inheritance

Constructors

SenderMessage({required String timestamp, required String name, required List<MessageElement> elements, bool isLoading = false, bool isFailed = false, bool? isRead, String? id, double? width})

Properties

elements List<MessageElement>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
isFailed bool
finalinherited
isLoading bool
finalinherited
isRead bool?
finalinherited
isSender bool
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String
finalinherited
width double?
finalinherited

Methods

copyWith({String? id, bool? isLoading, List<MessageElement>? elements, bool? isFailed, bool? isRead, String? timestamp, double? width}) SenderMessage
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited