ChatConfiguration class

Constructors

ChatConfiguration({ChatAlignment senderAlignment = ChatAlignment.end, Widget newReceiveMessageNotificationBuilder(BuildContext, Message, ChatController)?, BubbleConfiguration bubbleConfiguration = const BubbleConfiguration(), Widget? readOnlyWidget, double newMessageScrollThreshold = 300, Widget dateSeparatorBuilder(BuildContext context, String name)?, TextStyle? dateSeparatorStyle})
const

Properties

bubbleConfiguration BubbleConfiguration
final
dateSeparatorBuilder Widget Function(BuildContext context, String name)?
final
dateSeparatorStyle TextStyle?
final
hashCode int
The hash code for this object.
no setterinherited
isPrevProfile bool
no setter
newMessageScrollThreshold double
final
newReceiveMessageNotificationBuilder Widget Function(BuildContext, Message, ChatController)?
final
readOnlyWidget Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderAlignment ChatAlignment
final

Methods

buildDateDivider(BuildContext context, String timestamp) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited