ChatController class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
addMessage(Message message)
→ MessageGroup
-
-
animateTo(double offset, {required Duration duration, required Curve curve})
→ Future<void>
-
Animates the position from its current value to the given value.
inherited
-
appendMessages(List<Message> messages)
→ void
-
-
attach(ScrollPosition position)
→ void
-
Register the given position with this controller.
inherited
-
containsMessageId(String messageId)
→ bool
-
-
createScrollPosition(ScrollPhysics physics, ScrollContext context, ScrollPosition? oldPosition)
→ ScrollPosition
-
Creates a ScrollPosition for use by a Scrollable widget.
inherited
-
debugFillDescription(List<String> description)
→ void
-
Add additional information to the given description for use by toString.
inherited
-
detach(ScrollPosition position)
→ void
-
Unregister the given position with this controller.
inherited
-
dispatchMessage(Message message, {required MessageDispatchCallback onDispatch})
→ Future<MessageDispatchResult>
-
-
dispose()
→ void
-
Discards any resources used by the object.
override
-
isAtBottom({double threshold = 20})
→ bool
-
-
isDateChangedComparedTo(Message message, Message other)
→ bool
-
-
isSameMinute(DateTime a, DateTime b)
→ bool
-
-
jumpTo(double value)
→ void
-
Jumps the scroll position from its current value to the given value,
without animation, and without checking if the new value is in range.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
override
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeMessageEverywhere(Message message)
→ void
-
-
removeMessageFromGroup(MessageGroup group, Message message)
→ void
-
-
removeMessageGroupAt(MessageGroup group, int messageIndex)
→ void
-
-
retryMessage(Message message)
→ Future
-
-
scrollToBottom()
→ void
-
-
scrollToBottomByValue(double offset)
→ void
-
-
scrollToTopByValue(double offset)
→ void
-
-
setIsCollapsed(bool value)
→ void
-
-
setMessages(List<Message> messages)
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateMessageAllRead()
→ void
-