Message class abstract
- Implementers
Constructors
Properties
-
elements
→ List<
MessageElement> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isFailed → bool
-
final
- isLoading → bool
-
final
- isRead → bool?
-
final
- isSender → bool
-
no setter
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → String
-
final
- width → double?
-
final
Methods
-
copyWith(
{String? id, String? timestamp, bool? isLoading, List< MessageElement> ? elements, bool? isFailed, double? width, bool? isRead}) → Message -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited